# ##################################
# programme permettant d'importer des données de pointage
# pour les programmes python de mécanique du programme de
# seconde et première
# #################################
# Olivier CHAUMETTE / Jean-Baptiste BUTET
# Académie de LYON
# #################################

# ##########################
# IMPORTATION DES MODULES #
# #########################
# importation de NUMPY (pour gestion tableaux et calculs) sous l'alias "np"
import numpy as np
# importation de PYPLOT (du module MATPLOTLIB, pour le tracé de courbes) sous l'alias "plt"
import matplotlib.pyplot as plt

# modules pour gérer la boite de dialogue demandant un nom de fichier
import os
from tkinter import *
from tkinter.filedialog import *
import csv


def traiteDonnees(origine):
    """ CHOIX DU PROFESSEUR ICI
    - soit x et y des points sont issues d'un pointage (conseillé) puis mises dans les taleaux
    x et y à la main (laborieux) ou bien via un fichier cvs (notions de programmation indispensable)
    - soit x et y sont issues d'équations horaires proposées par le professeur (rapide)
    """

    if origine != 'equation' or origine != 'entree':
        Fenetre=Tk()
    t = np.array([])
    x = np.array([])
    y = np.array([])

    if origine=='entree':
        """ CAS 1:
        X ET Y ISSUES DU POINTAGE et entrées à la main:
        on met les abscisses, les ordonnées, les dates dans 3 tableaux
        ces 3 tableaux pourront être récupérés plus tard via un fichier"""

        x=np.array([0,0,0,0,0,0,0,0,0])
        y=np.array([9.86E-3,-5.92e-2,-1.48E-1,-2.76e-1,-4.24E-1,-6.02E-1,-8.48E-1,-1.07,-1.39])
        t=np.array([0,0.033,0.067,0.1,0.133,0.167,0.2,0.233,0.267])
        Nbre_Mesures=len(x)

    elif origine=='equation':
        """ CAS 2:
        X ET Y ISSUES D'EQUATIONS HORAIRES DONNEES PAR LE PROFESSEUR
        (méthode rapide)"""
        tmax = 2 #<- val maxi de t en seconde
        Nbre_Mesures = 20 # <- Nbre de points voulus. L'intervalle de temps sera tmax/Nbre_Points
        t = np.linspace(0, tmax,Nbre_Mesures)    #<- on créé un tableau numpy de dates
        x=2*t              # <- on met dans la liste x la valeur de l'equation paramétrée x(t)
        y=-4.9*t*t+2*t+1   # <- on met dans la liste y la valeur de l'equation paramétrée y(t)

    elif origine=='avistep':
        """CAS 3: OUVERTURE A PARTIR D'UN FICHIER DE POINTAGE AVISTEP version 2 (gratuite)
        Cette partie dépend de la structure du fichier sauvegardé par les logiciels de pointage.
        Dans le fichier TXT créé par AVISTEP version 2, les 1ères lignes sont vides puis
        on retrouve les noms des colonnes et les unités. Les données sont séparées par des TABULATIONS."""

        Nom_fichier=askopenfilename(title="Ouvrir le fichier de Pointage", initialdir=os.getcwd(), initialfile="*.txt", filetypes = [("Fichiers Textes tabulés CSV","*.txt;*.csv"),("All", "*")])
        Fichier_Csv = open(Nom_fichier, 'r')
        Objet_Reader_Csv=csv.reader(Fichier_Csv,delimiter = '\t')   # on créée un objet csv, le délimiteur étant TAB
        for Ligne in Objet_Reader_Csv:                              # on parcourt chaque ligne du fichier tabulé (chaque ligne est une liste)
            #    print (Ligne)
            if len(Ligne)!=0 and Ligne!=['Numero', 'Date', 'x1', 'y1', ''] and Ligne!=['', '(s)', '(m)', '(m)', '']:    # si ligne avec des "vraies" données
                var_temp=Ligne[2]                          # on récupère le 2nd élément de la liste correspondante à une ligne: c'est x
                var_temp=var_temp.replace(",",".")            # on remplace les "," par des "." pour que Python comprenne
                x=np.append(x,float(var_temp))                   # on ajoute à la liste "x" la valeur entière correspondant à la donnée
                y=np.append(y,float(Ligne[3].replace(",",".")))      # idem pour y (3ème colonne) en une ligne d'instruction
                t=np.append(t,float(Ligne[1].replace(",",".")))    # idem pour les dates (1ère colonne)
        Nbre_Mesures=len(x)                            # le nombre de mesures (longueur de liste x ou y ou t)
        Fichier_Csv.close()

    elif origine=='latispro':
        """CAS 4:
        OUVERTURE A PARTIR D'UN FICHIER DE POINTAGE LATISPRO sauvegardé au format TXT
         Dans le fichier TXT créé par LATISPRO, avec décimale VIRGULE et séparation POINT VIRGULE
        ATTENTION, à l'export depuis Latispro, il faut avoir précisé: Décimal: virgule et Séparateur: Point virgule"""

        Nom_fichier=askopenfilename(title="Ouvrir le fichier de Pointage", initialdir=os.getcwd(), initialfile="*.txt", filetypes = [("Fichiers Textes tabulés CSV","*.txt;*.csv"),("All", "*")])
        Fichier_Csv = open(Nom_fichier, 'r')
        Objet_Reader_Csv=csv.reader(Fichier_Csv,delimiter = ';')   # on créée un objet csv, le délimiteur étant ;
        for Ligne in Objet_Reader_Csv:                              # on parcourt chaque ligne du fichier tabulé (chaque ligne est une liste)
            if len(Ligne)!=0 and Ligne!=['Temps', 'Mouvement X', 'Temps','Mouvement Y']:    # si ligne avec des "vraies" données
                x=np.append(x,float(Ligne[1].replace(",",".")))        # on ajoute à la liste "x" la valeur entière correspondant à la donnée
                y=np.append(y,float(Ligne[3].replace(",",".")))      # idem pour y (3ème colonne) en une ligne d'instruction
                t=np.append(t,float(Ligne[0].replace(",",".")))    # idem pour les dates (1ère colonne)
        Nbre_Mesures=len(x)
        Fichier_Csv.close()

    elif origine == 'avimeca':
        """ CAS 5:
            OUVERTURE A PARTIR D'UN FICHIER DE POINTAGE AVIMECA (gratuite)
             Les données sont séparées par des TABULATIONS
             Bien faire ce choix fait à l'export depuis AVIMECA"""
        Nom_fichier=askopenfilename(title="Ouvrir le fichier de Pointage", initialdir=os.getcwd(), initialfile="*.txt", filetypes = [("Fichiers Textes tabulés CSV","*.txt;*.csv"),("All", "*")])
        Fichier_Csv = open(Nom_fichier, 'r', encoding='latin-1')
        Objet_Reader_Csv=csv.reader(Fichier_Csv,delimiter = '\t')
        for Ligne in Objet_Reader_Csv:                              # on parcourt chaque ligne du fichier tabulé (chaque ligne est une liste)
            print (Ligne)
            if Objet_Reader_Csv.line_num!=1 and Ligne!=['t', 'x', 'y'] and Ligne!=['(s)', '(m)', '(m)']:    # si ligne avec des "vraies" données
                var_temp=Ligne[1]                          # on récupère le 2nd élément de la liste correspondante à une ligne: c'est x
                var_temp=var_temp.replace(",",".")            # on remplace les "," par des "." pour que Python comprenne
                x=np.append(x,float(var_temp))                   # on ajoute à la liste "x" la valeur entière correspondant à la donnée
                y=np.append(y,float(Ligne[2].replace(",",".")))      # idem pour y (3ème colonne) en une ligne d'instruction
                t=np.append(t,float(Ligne[0].replace(",",".")))    # idem pour les dates (1ère colonne)

        Fichier_Csv.close()

    elif origine == 'pymecavideo':
        """CAS 6:
        OUVERTURE A PARTIR D'UN FICHIER DE POINTAGE PYMECAVIDEO (gratuit, libre et multiplateforme)
        Dans le fichier CSV créé par PYMECAVIDEO, les lignes avec un dièse son inutiles
        on retrouve les noms des colonnes et les unités. Les données sont séparées par des VIRGULES"""
        Nom_fichier=askopenfilename(title="Ouvrir le fichier de Pointage", initialdir=os.getcwd(), initialfile="*.csv;*.txt", filetypes = [("Fichiers Textes tabulés CSV","*.txt;*.csv"),("All", "*.csv;*.txt")])
        Fichier_Csv = open(Nom_fichier, 'r')
        for ligne in Fichier_Csv:
            if not '#' in ligne :
                t = np.append(t, float(ligne.split()[0].replace(',','.'))) #on remplace la virgule par un point dans les données pour qu'elles soient bien lues comme des nombres
                print(ligne.split())
                x = np.append(x , float(ligne.split()[1].replace(',','.')))
                y = np.append(y , float(ligne.split()[2].replace(',','.')))
        Fichier_Csv.close()
    Nbre_Mesures=len(x)                            # le nombre de mesures (longueur de liste x ou y ou t)

    try :
        Fenetre.destroy()
    except : pass
    return t, x, y
